/*
 * Sixth 3D engine. Copyright ©2012-2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 *
 */

package eu.svjatoslav.sixth.e3d.renderer.octree.raytracer;

import eu.svjatoslav.sixth.e3d.geometry.Point3D;
import eu.svjatoslav.sixth.e3d.gui.Avatar;

public class CameraView {

    Point3D camCenter;
    Point3D upLeft;
    Point3D upRight;
    Point3D downLeft;
    Point3D downRight;

    public CameraView(final Avatar avatar, final double zoom) {
        computeCameraCoordinates(avatar, zoom);
    }

    private void computeCameraCoordinates(final Avatar avatar, final double zoom) {
        camCenter = new Point3D(avatar.getLocation()).scaleDown(zoom);

        upLeft = new Point3D(camCenter.x, camCenter.y, camCenter.z
                + Camera.CAMERA_SIZE);
        upRight = new Point3D(upLeft);
        downLeft = new Point3D(upLeft);
        downRight = new Point3D(upLeft);

        final float viewAngle = (float) .6;

        upLeft.rotate(camCenter, -viewAngle, -viewAngle);
        upRight.rotate(camCenter, viewAngle, -viewAngle);
        downLeft.rotate(camCenter, -viewAngle, viewAngle);
        downRight.rotate(camCenter, viewAngle, viewAngle);

        upLeft.rotate(camCenter, -avatar.getAngleXZ(), -avatar.getAngleYZ());
        upRight.rotate(camCenter, -avatar.getAngleXZ(), -avatar.getAngleYZ());
        downLeft.rotate(camCenter, -avatar.getAngleXZ(), -avatar.getAngleYZ());
        downRight.rotate(camCenter, -avatar.getAngleXZ(), -avatar.getAngleYZ());
    }

}
