/*
 * Sixth 3D engine. Copyright ©2012-2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 *
 */

package eu.svjatoslav.sixth.e3d.renderer.raster.shapes.composite.wireframe;

import eu.svjatoslav.sixth.e3d.geometry.Point3D;
import eu.svjatoslav.sixth.e3d.renderer.raster.shapes.basic.line.LineAppearance;
import eu.svjatoslav.sixth.e3d.renderer.raster.shapes.composite.base.AbstractCompositeShape;

import java.util.ArrayList;

public class WireframeSphere extends AbstractCompositeShape {

    ArrayList<Point3D> previousRing = new ArrayList<>();

    public WireframeSphere(final Point3D location, final float radius,
                           final LineAppearance lineFactory) {
        super(location);

        final double step = Math.PI / 10;

        final Point3D center = new Point3D();

        int ringIndex = 0;

        for (double j = 0d; j <= (Math.PI * 2); j += step) {

            Point3D oldPoint = null;
            int pointIndex = 0;

            for (double i = 0; i <= (Math.PI * 2); i += step) {
                final Point3D newPoint = new Point3D(0, 0, radius);
                newPoint.rotate(center, i, j);

                if (oldPoint != null)
                    addShape(lineFactory.getLine(newPoint, oldPoint));

                if (ringIndex > 0) {
                    final Point3D previousRingPoint = previousRing
                            .get(pointIndex);
                    addShape(lineFactory.getLine(newPoint, previousRingPoint));

                    previousRing.set(pointIndex, newPoint);
                } else
                    previousRing.add(newPoint);

                oldPoint = newPoint;
                pointIndex++;
            }

            ringIndex++;
        }

    }

}
